import { Credential, PrimaryClientConfiguration } from '../protocol/data';
import { DisplayOptions } from '../protocol/rpc_messages';
export interface ProviderConfiguration {
    clientAuthDomain: string;
    clientNonce: string;
    window: WindowLike;
    delegateToBrowser: boolean;
    affiliationProvider: AffiliationProvider;
    clientConfigurationProvider: ClientConfigurationProvider;
    credentialDataProvider: CredentialDataProvider;
    interactionProvider: InteractionProvider;
    localStateProvider: LocalStateProvider;
    allowDirectAuth: boolean;
}
export interface WindowLike extends EventTarget {
    parent: WindowLike;
    opener: WindowLike | null;
    close(): void;
    postMessage(data: any, targetOrigin: string, transfer?: MessagePort[]): void;
}
export interface AffiliationProvider {
    getEquivalentDomains(authDomain: string): Promise<string[]>;
}
export interface ClientConfigurationProvider {
    getConfiguration(authDomain: string): Promise<PrimaryClientConfiguration>;
}
export interface CredentialDataProvider {
    getAllCredentials(authDomains?: string[]): Promise<Credential[]>;
    upsertCredential(credential: Credential, original?: Credential): Promise<Credential>;
    deleteCredential(credential: Credential): Promise<void>;
}
export interface DisplayCallbacks {
    requestDisplayOptions(options: DisplayOptions): void;
}
export interface InteractionProvider {
    showCredentialPicker(credentials: Credential[], displayCallbacks: DisplayCallbacks): Promise<Credential>;
    showHintPicker(hints: Credential[], displayCallbacks: DisplayCallbacks): Promise<Credential>;
    showSaveConfirmation(credential: Credential, displayCallbacks: DisplayCallbacks): Promise<boolean>;
    dispose(): void;
}
export interface LocalStateProvider {
    isAutoSignInEnabled(authDomain: string): Promise<boolean>;
    setAutoSignInEnabled(authDomain: string, enabled: boolean): Promise<void>;
    retainCredentialForSession(authDomain: string, credential: Credential): Promise<void>;
    getRetainedCredential(authDomain: string): Promise<Credential>;
}
